"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "color-hex-case";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(c, h) {
    return "Expected " + c + "case hex color " + h;
  }
});

exports.messages = messages;
/**
 * @param {"lower"|"upper"} expectation
 */

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: "#" }, function (match) {

        var hexValue = /^#[0-9A-Za-z]+/.exec(value.substr(match.startIndex))[0];

        if (expectation === "lower" && hexValue === hexValue.toLowerCase()) {
          return;
        }

        if (expectation === "upper" && hexValue === hexValue.toUpperCase()) {
          return;
        }

        (0, _utils.report)({
          message: messages.expected(expectation, hexValue),
          node: decl,
          result: result,
          ruleName: ruleName
        });
      });
    });
  };
};